//JOBCRDP$ JOB (001),'JOBCRD SUBROUTINE',CLASS=S,MSGCLASS=X
//JOBCRD  EXEC ASMFCL,PARM.ASM='LIST,LOAD,NODECK'
//ASM.SYSIN DD *
         TITLE 'WRAPPER FOR JOBCRD FOR PL/1 F'
JOBCRDP  CSECT                         DEFINE CSECT
***********************************************************************
*
*    ROUTINE NAME ---------> JOBCRDP
*
*    ENTRY POINTS ---------> -NONE-
*
*    EXTERNAL REFERENCES --> -NONE-
*
*    PL/I F PARMS ARE DIFFERENT THAN STANDARD PARMS.  CHARACTER
*    FIELDS ARE FOLLOWED BY 2 HALF WORDS GIVING THE LENGTH OF THE
*    FIELD.  NUMERIC BINARY ITEMS (WORDS AND HALF WORD) ONLY HAVE
*    TO ADDRESS.  BELOW IS A MAPPING OF ALL THE FIELDS BEING PASSED
*    TO THIS ROUTINE.
*
*    STRUCTURES ALSO ARE DIFFERENT THAN STANDARD PARMS.  THE
*    ADDRESS OF A "DOPE" VECTOR IS POINTED TO IN THE PARM LIST.
*    THE FIRST WORD OF THE VECTOR IS THE ADDRESS OF THE STRUCTURE.
*
*
*      DECLARE
*        1  PARAMETER_BLOCK  STATIC,
*            3  PB_JOBNAME              CHAR(8),
*            3  PB_MSGCLASS             CHAR(1),
*            3  PB_PRIORITY             FIXED BINARY,
*            3  PB_REGION               FIXED BINARY,
*            3  PB_TIME                 FIXED BINARY(31),
*            3  PB_NAME                 CHAR(20),
*            3  PB_ACCOUNT              CHAR(50),
*            3  PB_ACCOUNTL             FIXED BINARY,
*            3  PB_ROOM                 CHAR(50),
*            3  PB_ROOML                FIXED BINARY,
*            3  PB_JOBCLASS             CHAR(1),
*            3  PB_JES2NUMBER           CHAR(4);
*
*      CALL JOBCRDP(PARAMETER_BLOCK);
*
*    GENERATES THE PARM LIST:
*
*    PARMS ----------------> ADDRESS OF PARAMETER_BLOCK VECTOR
*                                       AL1(X'80)
*                                       AL3(PBVECTOR)
*                            .....
*                            PBVECTOR  +0 A(PARAMETER_BLOCK)
*
*
*      CALL JOBCRDP(
*               PB_JOBNAME,
*               PB_MSGCLASS,
*               PB_PRIORITY,
*               PB_REGION,
*               PB_TIME,
*               PB_NAME,
*               PB_ACCOUNT,
*               PB_ACCOUNTL,
*               PB_ROOM,
*               PB_ROOML,
*               PB_JOBCLASS,
*               PB_JES2NUMBER);
*
*    GENERATES THE PARM LIST:
*
*    PARMS ----------------> JOBNAME  -  8 BYTE JOBNAME
*                                        X'00080008'
*                            MSGCLASS -  1 BYTE MESSAGE CLASS
*                                        X'00010001'
*                            PRIORITY -  2 BYTE INTEGER PRIORITY
*                            REGION   -  2 BYTE INTEGER REGION
*                                          (IN KBYTES)
*                            TIME     -  4 BYTE INTEGER TIME LIMIT
*                                          (IN HUNDREDTHS OF SECONDS)
*                            NAME     - 20 BYTE PROGRAMMER NAME
*                                        X'00140014'
*                            ACCOUNT  - 50 BYTE ACCOUNTING FIELD
*                                        X'00320032'
*                            ACCTLEN  -  2 BYTE INTEGER ACNT FIELD LEN
*                            ROOM     - 50 BYTE ROOM FIELD
*                                        X'00320032'
*                            ROOMLEN  -  2 BYTE INTEGER ROOM FIELD LEN
*                            JOBCLASS -  1 BYTE JOB CLASS
*                                        X'00010001'
*                            JES#     -  4 JES NUMBER
*                                        X'00040004'
*
*    DATE LAST MODIFIED ---> 03/02/2023
*
*    ROUTINE DESCRIPTION:
*         THIS ROUTINE IS A WRAPPER FOR JOBCRD SO PL/1 PROGRAMS
*    CAN GET THE JOB CARD INFO.
*
*
***********************************************************************
*
*     REGISTER EQUATES AND USAGE
*
R0       EQU   0
R1       EQU   1
R2       EQU   2
R3       EQU   3
R4       EQU   4
R5       EQU   5
R6       EQU   6
R7       EQU   7
R8       EQU   8                       TCT, THEN JMR ADDR
R9       EQU   9                       ACT ADDR
R10      EQU   10                      JCT ADDR
R11      EQU   11                      WORKAREA BASE REG
R12      EQU   12                      BASE REG
R13      EQU   13                      SAVE AREA ADDR
R14      EQU   14                      RETURN ADDR
R15      EQU   15                      RETURN CODE
*
*     HOUSEKEEPING
*
         STM   R14,R12,12(R13)         SAVE REGISTERS
         LR    R12,R15                 SET REG 12 TO ENTRY ADDR
         USING JOBCRDP,R12             ESTABLISH ADDRESSABILITY
         LR    R10,R1                  SAVE R1
         LR    R2,R13                  SAVE ADDR OF CALLING SAVE AREA
         GETMAIN RU,LV=WORKSIZE        GET SOME CORE
         LR    R13,R1                  SAVE ADDR OF CORE OBTAINED
         USING WORKAREA,R13            ESTABLISH ADDRESSABILITY
         ST    R2,SAVEAREA+4           STORE ADDR OF CALLING SAVE AREA
         ST    R13,8(R2)               STORE ADDR OF MY SAVE AREA
*
*     DETERMINE IF THE PARM IS A STRUCTURE OR INDIVIDUAL FIELDS.
*
         L     R9,0(,R10)
         USING $PL1PARM,R9
         TM    0(R10),X'80'             ONLY 1 PARM?
         BZ    MOVEFLDS                 NO, CALL WITH ALL 12.
*
*     GENERATE THE STANDARD PARM LIST FROM ADDRESSES RELATIVE TO
*     THE STRUCTRE. THE ACTUAL ADDRS OF THE DATA ITEMS - NOT VECTORS
*
         L     R10,0(R10)               GET ADDR OF VECTOR
         L     R10,0(R10)               GET ADDR OF BLOCK
         USING #PL1PARM,R10
         LA    R2,#JOBNAME
         ST    R2,JOBNPTR
         LA    R2,#MSGCLAS
         ST    R2,MSGCPTR
         LA    R2,#PRIORIT
         ST    R2,PRTYPTR
         LA    R2,#REGION
         ST    R2,REGNPTR
         LA    R2,#TIME
         ST    R2,TIMEPTR
         LA    R2,#NAME
         ST    R2,NAMEPTR
         LA    R2,#ACCOUNT
         ST    R2,ACCTPTR
         LA    R2,#ACOUNTL
         ST    R2,ACTLPTR
         LA    R2,#ROOM
         ST    R2,ROOMPTR
         LA    R2,#ROOML
         ST    R2,ROMLPTR
         LA    R2,#JOBCLAS
         ST    R2,CLASPTR
         LA    R2,#JES2#NM
         ST    R2,JES#PTR
         B     CALLIT
*
MOVEFLDS EQU   *
*
*     COPY THE PL/1 PARMS TO A STANDARD PARM LIST
*     THESE ARE THE ACTUAL ADDRS OF THE DATA ITEMS - NOT VECTORS
*
         MVC   JOBNPTR,$JOBNPTR
         MVC   MSGCPTR,$MSGCPTR
         MVC   PRTYPTR,$PRTYPTR
         MVC   REGNPTR,$REGNPTR
         MVC   TIMEPTR,$TIMEPTR
         MVC   NAMEPTR,$NAMEPTR
         MVC   ACCTPTR,$ACCTPTR
         MVC   ACTLPTR,$ACTLPTR
         MVC   ROOMPTR,$ROOMPTR
         MVC   ROMLPTR,$ROMLPTR
         MVC   CLASPTR,$CLASPTR
         MVC   JES#PTR,$JES#PTR
*
*      NOW CALL JOBCRD
*
CALLIT   EQU   *
         LA    R1,PARMPTRS
         L     R15,=V(JOBCARD)
         BALR  R14,R15
*
*     TERMINATE
*
         LR    R1,R13                  SAVE PTR TO GETMAINED SAVE AREA
         LR    R2,R15                  SAVE RETURN CODE
         L     R13,SAVEAREA+4          LOAD ADDR OF CALLING SAVE AREA
         FREEMAIN R,LV=WORKSIZE,A=(R1) FREE THE CORE WE GOT
         LR    R15,R2                  PUT RETURN CODE IN R15
         L     R14,12(R13)             RESTORE R14
         LM    R0,R12,20(R13)          RESTORE R0 THROUGH R12
         BR    R14                     RETURN
*
*     DSECTS
*
WORKAREA DSECT
SAVEAREA DS    18F
PARMPTRS DS    0F
JOBNPTR  DS    F
MSGCPTR  DS    F
PRTYPTR  DS    F
REGNPTR  DS    F
TIMEPTR  DS    F
NAMEPTR  DS    F
ACCTPTR  DS    F
ACTLPTR  DS    F
ROOMPTR  DS    F
ROMLPTR  DS    F
CLASPTR  DS    F
JES#PTR  DS    F
PARMLEN  EQU   *-PARMPTRS
WORKSIZE EQU   *-WORKAREA
$PL1PARM DSECT
$JOBNPTR  DS    F
          DS    F
$MSGCPTR  DS    F
          DS    F
$PRTYPTR  DS    F
$REGNPTR  DS    F
$TIMEPTR  DS    F
$NAMEPTR  DS    F
          DS    F
$ACCTPTR  DS    F
          DS    F
$ACTLPTR  DS    F
$ROOMPTR  DS    F
          DS    F
$ROMLPTR  DS    F
$CLASPTR  DS    F
          DS    F
$JES#PTR  DS    F
          DS    F
#PL1PARM  DSECT
#JOBNAME  DS    CL8
#MSGCLAS  DS    C
#PRIORIT  DS    XL2
#REGION   DS    XL2
#TIME     DS    XL4
#NAME     DS    CL20
#ACCOUNT  DS    CL50
#ACOUNTL  DS    XL2
#ROOM     DS    CL50
#ROOML    DS    XL2
#JOBCLAS  DS    C
#JES2#NM  DS    CL4
         END   JOBCRDP
//LKED.SYSLMOD DD DSN=SYSC.LINKLIB,DISP=SHR
//LKED.SYSLIB  DD DSN=SYSC.LINKLIB,DISP=SHR
//LKED.SYSIN   DD *
  INCLUDE SYSLIB(JOBCARD)
  NAME JOBCRDP(R)
//
